import { ActionBar } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/actionbar/actionbar";
import { HighlightedLabel, IHighlight } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/highlightedlabel/highlightedLabel";
import { IInputValidationOptions } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/inputbox/inputBox";
import { IAsyncDataSource, ITreeNode, ITreeRenderer } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/tree/tree";
import { FuzzyScore } from "@codingame/monaco-vscode-api/vscode/vs/base/common/filters";
import { DisposableStore, IDisposable } from "@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle";
import { ICommandService } from "@codingame/monaco-vscode-api/vscode/vs/platform/commands/common/commands.service";
import { IContextViewService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextview/browser/contextView.service";
import { IHoverService } from "@codingame/monaco-vscode-api/vscode/vs/platform/hover/browser/hover.service";
import { IExpression } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debug";
import { IDebugService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debug.service";
import { IDebugVisualizerService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debugVisualizers.service";
import { LinkDetector } from "@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/linkDetector";
export interface IRenderValueOptions {
    showChanged?: boolean;
    maxValueLength?: number;
    hover?: false | {
        commands: {
            id: string;
            args: unknown[];
        }[];
        commandService: ICommandService;
    };
    colorize?: boolean;
    linkDetector?: LinkDetector;
}
export interface IVariableTemplateData {
    expression: HTMLElement;
    name: HTMLElement;
    type: HTMLElement;
    value: HTMLElement;
    label: HighlightedLabel;
    lazyButton: HTMLElement;
}
export declare function renderViewTree(container: HTMLElement): HTMLElement;
export interface IInputBoxOptions {
    initialValue: string;
    ariaLabel: string;
    placeholder?: string;
    validationOptions?: IInputValidationOptions;
    onFinish: (value: string, success: boolean) => void;
}
export interface IExpressionTemplateData {
    expression: HTMLElement;
    name: HTMLSpanElement;
    type: HTMLSpanElement;
    value: HTMLSpanElement;
    inputBoxContainer: HTMLElement;
    actionBar?: ActionBar;
    elementDisposable: DisposableStore;
    templateDisposable: IDisposable;
    label: HighlightedLabel;
    lazyButton: HTMLElement;
    currentElement: IExpression | undefined;
}
export declare abstract class AbstractExpressionDataSource<Input, Element extends IExpression> implements IAsyncDataSource<Input, Element> {
    protected debugService: IDebugService;
    protected debugVisualizer: IDebugVisualizerService;
    constructor(debugService: IDebugService, debugVisualizer: IDebugVisualizerService);
    abstract hasChildren(element: Input | Element): boolean;
    getChildren(element: Input | Element): Promise<Element[]>;
    protected abstract doGetChildren(element: Input | Element): Promise<Element[]>;
}
export declare abstract class AbstractExpressionsRenderer<T = IExpression> implements ITreeRenderer<T, FuzzyScore, IExpressionTemplateData> {
    protected debugService: IDebugService;
    private readonly contextViewService;
    protected readonly hoverService: IHoverService;
    constructor(debugService: IDebugService, contextViewService: IContextViewService, hoverService: IHoverService);
    abstract get templateId(): string;
    renderTemplate(container: HTMLElement): IExpressionTemplateData;
    abstract renderElement(node: ITreeNode<T, FuzzyScore>, index: number, data: IExpressionTemplateData): void;
    protected renderExpressionElement(element: IExpression, node: ITreeNode<T, FuzzyScore>, data: IExpressionTemplateData): void;
    renderInputBox(nameElement: HTMLElement, valueElement: HTMLElement, inputBoxContainer: HTMLElement, options: IInputBoxOptions): IDisposable;
    protected abstract renderExpression(expression: T, data: IExpressionTemplateData, highlights: IHighlight[]): void;
    protected abstract getInputBoxOptions(expression: IExpression, settingValue: boolean): IInputBoxOptions | undefined;
    protected renderActionBar?(actionBar: ActionBar, expression: IExpression, data: IExpressionTemplateData): void;
    disposeElement(node: ITreeNode<T, FuzzyScore>, index: number, templateData: IExpressionTemplateData): void;
    disposeTemplate(templateData: IExpressionTemplateData): void;
}
