
import { KeyMod, KeyCode } from '@codingame/monaco-vscode-api/vscode/vs/base/common/keyCodes';
import { FileAccess } from '@codingame/monaco-vscode-api/vscode/vs/base/common/network';
import { isWeb, isMacintosh } from '@codingame/monaco-vscode-api/vscode/vs/base/common/platform';
import './media/debug.contribution.css.js';
import './media/debugHover.css.js';
import { registerEditorContribution, EditorContributionInstantiation } from '@codingame/monaco-vscode-api/vscode/vs/editor/browser/editorExtensions';
import { localize, localize2 } from '@codingame/monaco-vscode-api/vscode/vs/nls';
import { AccessibleViewRegistry } from '@codingame/monaco-vscode-api/vscode/vs/platform/accessibility/browser/accessibleViewRegistry';
import { MenuRegistry, MenuId } from '@codingame/monaco-vscode-api/vscode/vs/platform/actions/common/actions';
import { Extensions as Extensions$3, ConfigurationScope } from '@codingame/monaco-vscode-api/vscode/vs/platform/configuration/common/configurationRegistry';
import { ContextKeyExpr } from '@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey';
import { SyncDescriptor } from '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/descriptors';
import '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/extensions';
import { Extensions as Extensions$1 } from '@codingame/monaco-vscode-api/vscode/vs/platform/quickinput/common/quickAccess';
import { Registry } from '@codingame/monaco-vscode-api/vscode/vs/platform/registry/common/platform';
import { EditorPaneDescriptor } from '@codingame/monaco-vscode-9e888134-1a6f-58d9-b0e6-0fc047448366-common/vscode/vs/workbench/browser/editor';
import { ViewPaneContainer } from '@codingame/monaco-vscode-9e888134-1a6f-58d9-b0e6-0fc047448366-common/vscode/vs/workbench/browser/parts/views/viewPaneContainer';
import { Extensions, registerWorkbenchContribution2, WorkbenchPhase } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/contributions';
import { EditorExtensions } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/editor';
import { Extensions as Extensions$2, ViewContainerLocation } from '@codingame/monaco-vscode-api/vscode/vs/workbench/common/views';
import { BreakpointEditorContribution } from '@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/breakpointEditorContribution';
import { BreakpointsView } from '@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/breakpointsView';
import { CallStackEditorContribution } from '@codingame/monaco-vscode-0b087f42-a5a3-5eb9-9bfd-1eebc1bba163-common/vscode/vs/workbench/contrib/debug/browser/callStackEditorContribution';
import { CallStackView } from './callStackView.js';
import { ReplAccessibleView } from './replAccessibleView.js';
import { registerColors } from '@codingame/monaco-vscode-fc42f049-7883-579d-bb0b-2aa1010a19a8-common/vscode/vs/workbench/contrib/debug/browser/debugColors';
import { DEBUG_QUICK_ACCESS_PREFIX, SELECT_AND_START_ID, DEBUG_CONSOLE_QUICK_ACCESS_PREFIX, SELECT_DEBUG_CONSOLE_ID, DEBUG_COMMAND_CATEGORY, RESTART_SESSION_ID, RESTART_LABEL, TERMINATE_THREAD_ID, STEP_OVER_ID, STEP_OVER_LABEL, STEP_INTO_ID, STEP_INTO_LABEL, STEP_INTO_TARGET_ID, STEP_INTO_TARGET_LABEL, STEP_OUT_ID, STEP_OUT_LABEL, PAUSE_ID, PAUSE_LABEL, DISCONNECT_ID, DISCONNECT_LABEL, DISCONNECT_AND_SUSPEND_ID, DISCONNECT_AND_SUSPEND_LABEL, STOP_ID, STOP_LABEL, CONTINUE_ID, CONTINUE_LABEL, FOCUS_REPL_ID, JUMP_TO_CURSOR_ID, TOGGLE_INLINE_BREAKPOINT_ID, DEBUG_START_COMMAND_ID, DEBUG_START_LABEL, DEBUG_RUN_COMMAND_ID, DEBUG_RUN_LABEL, SELECT_AND_START_LABEL, NEXT_DEBUG_CONSOLE_ID, NEXT_DEBUG_CONSOLE_LABEL, PREV_DEBUG_CONSOLE_ID, PREV_DEBUG_CONSOLE_LABEL, SHOW_LOADED_SCRIPTS_ID, OPEN_LOADED_SCRIPTS_LABEL, SELECT_DEBUG_CONSOLE_LABEL, SELECT_DEBUG_SESSION_ID, SELECT_DEBUG_SESSION_LABEL, CALLSTACK_TOP_ID, CALLSTACK_TOP_LABEL, CALLSTACK_BOTTOM_ID, CALLSTACK_BOTTOM_LABEL, CALLSTACK_UP_ID, CALLSTACK_UP_LABEL, CALLSTACK_DOWN_ID, CALLSTACK_DOWN_LABEL, RESTART_FRAME_ID, COPY_STACK_TRACE_ID, COPY_VALUE_ID, COPY_VALUE_LABEL, COPY_EVALUATE_PATH_ID, COPY_EVALUATE_PATH_LABEL, ADD_TO_WATCH_ID, ADD_TO_WATCH_LABEL, EDIT_EXPRESSION_COMMAND_ID, SET_EXPRESSION_COMMAND_ID, REMOVE_EXPRESSION_COMMAND_ID, ADD_CONFIGURATION_ID } from '@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/debugCommands';
import { DebugConsoleQuickAccess } from './debugConsoleQuickAccess.js';
import { RunToCursorAction, SelectionToReplAction, SelectionToWatchExpressionsAction } from './debugEditorActions.js';
import { DebugEditorContribution } from './debugEditorContribution.js';
import { debugInspectMemory, watchExpressionRemove, debugRun, debugConsoleViewIcon, runViewIcon, variablesViewIcon, watchViewIcon, callStackViewIcon, breakpointsViewIcon, loadedScriptsViewIcon } from '@codingame/monaco-vscode-fc42f049-7883-579d-bb0b-2aa1010a19a8-common/vscode/vs/workbench/contrib/debug/browser/debugIcons';
import { DebugProgressContribution } from './debugProgress.js';
import { StartDebugQuickAccessProvider } from './debugQuickAccess.js';
import './debugService.js';
import { DebugStatusContribution } from './debugStatus.js';
import { DebugTitleContribution } from './debugTitle.js';
import { DebugToolBar } from './debugToolBar.js';
import { DebugViewPaneContainer } from './debugViewlet.js';
import { DisassemblyViewContribution, DisassemblyView } from './disassemblyView.js';
import { LoadedScriptsView } from './loadedScriptsView.js';
import { Repl } from './repl.js';
import { StatusBarColorProvider } from './statusbarColorProvider.js';
import { VIEW_MEMORY_ID, SET_VARIABLE_ID, BREAK_WHEN_VALUE_IS_READ_ID, BREAK_WHEN_VALUE_CHANGES_ID, BREAK_WHEN_VALUE_IS_ACCESSED_ID, VariablesView } from './variablesView.js';
import { ADD_WATCH_ID, ADD_WATCH_LABEL, REMOVE_WATCH_EXPRESSIONS_COMMAND_ID, REMOVE_WATCH_EXPRESSIONS_LABEL, WatchExpressionsView } from './watchExpressionsView.js';
import { WelcomeView } from './welcomeView.js';
import { BREAKPOINT_EDITOR_CONTRIBUTION_ID, EDITOR_CONTRIBUTION_ID, CONTEXT_DEBUGGERS_AVAILABLE, CONTEXT_IN_DEBUG_MODE, CONTEXT_DEBUG_STATE, CONTEXT_STEP_INTO_TARGETS_SUPPORTED, CONTEXT_FOCUSED_SESSION_IS_NO_DEBUG, CONTEXT_FOCUSED_SESSION_IS_ATTACH, CONTEXT_TERMINATE_DEBUGGEE_SUPPORTED, CONTEXT_SUSPEND_DEBUGGEE_SUPPORTED, CONTEXT_JUMP_TO_CURSOR_SUPPORTED, getStateLabel, State, CONTEXT_CALLSTACK_ITEM_TYPE, CONTEXT_RESTART_FRAME_SUPPORTED, CONTEXT_STACK_FRAME_SUPPORTS_RESTART, CONTEXT_CAN_VIEW_MEMORY, CONTEXT_SET_VARIABLE_SUPPORTED, CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, CONTEXT_SET_EXPRESSION_SUPPORTED, CONTEXT_VARIABLE_IS_READONLY, CONTEXT_BREAK_WHEN_VALUE_IS_READ_SUPPORTED, CONTEXT_BREAK_WHEN_VALUE_CHANGES_SUPPORTED, CONTEXT_BREAK_WHEN_VALUE_IS_ACCESSED_SUPPORTED, CONTEXT_WATCH_ITEM_TYPE, CONTEXT_VARIABLE_VALUE, DEBUG_PANEL_ID, REPL_VIEW_ID, VIEWLET_ID, VARIABLES_VIEW_ID, CONTEXT_DEBUG_UX, WATCH_VIEW_ID, CALLSTACK_VIEW_ID, BREAKPOINTS_VIEW_ID, CONTEXT_BREAKPOINTS_EXIST, CONTEXT_HAS_DEBUGGED, LOADED_SCRIPTS_VIEW_ID, CONTEXT_LOADED_SCRIPTS_SUPPORTED, DISASSEMBLY_VIEW_ID, INTERNAL_CONSOLE_OPTIONS_SCHEMA } from '@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debug';
import '@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation';
import { DebugContentProvider } from '../common/debugContentProvider.js';
import { DebugLifecycle } from '../common/debugLifecycle.js';
import '../common/debugVisualizers.js';
import { DisassemblyViewInput } from '@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/common/disassemblyViewInput';
import { COPY_NOTEBOOK_VARIABLE_VALUE_ID, COPY_NOTEBOOK_VARIABLE_VALUE_LABEL } from '../../notebook/browser/contrib/notebookVariables/notebookVariableCommands.js';
import { launchSchemaId } from '@codingame/monaco-vscode-37e80bf5-92f5-5e4c-8b6d-98e0bb89dbef-common/vscode/vs/workbench/services/configuration/common/configuration';
import { LifecyclePhase } from '@codingame/monaco-vscode-api/vscode/vs/workbench/services/lifecycle/common/lifecycle';
import './debugSettingMigration.js';
import { ReplAccessibilityHelp } from './replAccessibilityHelp.js';
import { ReplAccessibilityAnnouncer } from '../common/replAccessibilityAnnouncer.js';
import { RunAndDebugAccessibilityHelp } from './runAndDebugAccessibilityHelp.js';
import { DebugWatchAccessibilityAnnouncer } from '../common/debugAccessibilityAnnouncer.js';

const debugCategory = ( localize(5089, "Debug"));
registerColors();
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugStatusContribution, LifecyclePhase.Eventually);
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugProgressContribution, LifecyclePhase.Eventually);
if (isWeb) {
    ( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugTitleContribution, LifecyclePhase.Eventually);
}
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugToolBar, LifecyclePhase.Restored);
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugContentProvider, LifecyclePhase.Eventually);
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(StatusBarColorProvider, LifecyclePhase.Eventually);
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DisassemblyViewContribution, LifecyclePhase.Eventually);
( Registry.as(Extensions.Workbench)).registerWorkbenchContribution(DebugLifecycle, LifecyclePhase.Eventually);
( Registry.as(Extensions$1.Quickaccess)).registerQuickAccessProvider({
    ctor: StartDebugQuickAccessProvider,
    prefix: DEBUG_QUICK_ACCESS_PREFIX,
    contextKey: 'inLaunchConfigurationsPicker',
    placeholder: ( localize(5090, "Type the name of a launch configuration to run.")),
    helpEntries: [{
            description: ( localize(5091, "Start Debugging")),
            commandId: SELECT_AND_START_ID,
            commandCenterOrder: 50
        }]
});
( Registry.as(Extensions$1.Quickaccess)).registerQuickAccessProvider({
    ctor: DebugConsoleQuickAccess,
    prefix: DEBUG_CONSOLE_QUICK_ACCESS_PREFIX,
    contextKey: 'inDebugConsolePicker',
    placeholder: ( localize(5092, "Type the name of a debug console to open.")),
    helpEntries: [{ description: ( localize(5093, "Show All Debug Consoles")), commandId: SELECT_DEBUG_CONSOLE_ID }]
});
registerEditorContribution('editor.contrib.callStack', CallStackEditorContribution, EditorContributionInstantiation.AfterFirstRender);
registerEditorContribution(BREAKPOINT_EDITOR_CONTRIBUTION_ID, BreakpointEditorContribution, EditorContributionInstantiation.AfterFirstRender);
registerEditorContribution(EDITOR_CONTRIBUTION_ID, DebugEditorContribution, EditorContributionInstantiation.BeforeFirstInteraction);
const registerDebugCommandPaletteItem = (id, title, when, precondition) => {
    MenuRegistry.appendMenuItem(MenuId.CommandPalette, {
        when: ( ContextKeyExpr.and(CONTEXT_DEBUGGERS_AVAILABLE, when)),
        group: debugCategory,
        command: {
            id,
            title,
            category: DEBUG_COMMAND_CATEGORY,
            precondition
        }
    });
};
registerDebugCommandPaletteItem(RESTART_SESSION_ID, RESTART_LABEL);
registerDebugCommandPaletteItem(TERMINATE_THREAD_ID, ( localize2(5094, "Terminate Thread")), CONTEXT_IN_DEBUG_MODE);
registerDebugCommandPaletteItem(STEP_OVER_ID, STEP_OVER_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(STEP_INTO_ID, STEP_INTO_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(STEP_INTO_TARGET_ID, STEP_INTO_TARGET_LABEL, CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.and(CONTEXT_STEP_INTO_TARGETS_SUPPORTED, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')))));
registerDebugCommandPaletteItem(STEP_OUT_ID, STEP_OUT_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(PAUSE_ID, PAUSE_LABEL, CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.and(( CONTEXT_DEBUG_STATE.isEqualTo('running')), ( CONTEXT_FOCUSED_SESSION_IS_NO_DEBUG.toNegated()))));
registerDebugCommandPaletteItem(DISCONNECT_ID, DISCONNECT_LABEL, CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.or(CONTEXT_FOCUSED_SESSION_IS_ATTACH, CONTEXT_TERMINATE_DEBUGGEE_SUPPORTED)));
registerDebugCommandPaletteItem(DISCONNECT_AND_SUSPEND_ID, DISCONNECT_AND_SUSPEND_LABEL, CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.or(CONTEXT_FOCUSED_SESSION_IS_ATTACH, ( ContextKeyExpr.and(CONTEXT_SUSPEND_DEBUGGEE_SUPPORTED, CONTEXT_TERMINATE_DEBUGGEE_SUPPORTED)))));
registerDebugCommandPaletteItem(STOP_ID, STOP_LABEL, CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.or(( CONTEXT_FOCUSED_SESSION_IS_ATTACH.toNegated()), CONTEXT_TERMINATE_DEBUGGEE_SUPPORTED)));
registerDebugCommandPaletteItem(CONTINUE_ID, CONTINUE_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(FOCUS_REPL_ID, ( localize2(5095, "Focus on Debug Console View")));
registerDebugCommandPaletteItem(JUMP_TO_CURSOR_ID, ( localize2(5096, "Jump to Cursor")), CONTEXT_JUMP_TO_CURSOR_SUPPORTED);
registerDebugCommandPaletteItem(JUMP_TO_CURSOR_ID, ( localize2(5097, "Set Next Statement")), CONTEXT_JUMP_TO_CURSOR_SUPPORTED);
registerDebugCommandPaletteItem(RunToCursorAction.ID, RunToCursorAction.LABEL, CONTEXT_DEBUGGERS_AVAILABLE);
registerDebugCommandPaletteItem(SelectionToReplAction.ID, SelectionToReplAction.LABEL, CONTEXT_IN_DEBUG_MODE);
registerDebugCommandPaletteItem(SelectionToWatchExpressionsAction.ID, SelectionToWatchExpressionsAction.LABEL);
registerDebugCommandPaletteItem(TOGGLE_INLINE_BREAKPOINT_ID, ( localize2(5098, "Inline Breakpoint")));
registerDebugCommandPaletteItem(DEBUG_START_COMMAND_ID, DEBUG_START_LABEL, ( ContextKeyExpr.and(CONTEXT_DEBUGGERS_AVAILABLE, ( CONTEXT_DEBUG_STATE.notEqualsTo(getStateLabel(State.Initializing))))));
registerDebugCommandPaletteItem(DEBUG_RUN_COMMAND_ID, DEBUG_RUN_LABEL, ( ContextKeyExpr.and(CONTEXT_DEBUGGERS_AVAILABLE, ( CONTEXT_DEBUG_STATE.notEqualsTo(getStateLabel(State.Initializing))))));
registerDebugCommandPaletteItem(SELECT_AND_START_ID, SELECT_AND_START_LABEL, ( ContextKeyExpr.and(CONTEXT_DEBUGGERS_AVAILABLE, ( CONTEXT_DEBUG_STATE.notEqualsTo(getStateLabel(State.Initializing))))));
registerDebugCommandPaletteItem(NEXT_DEBUG_CONSOLE_ID, NEXT_DEBUG_CONSOLE_LABEL);
registerDebugCommandPaletteItem(PREV_DEBUG_CONSOLE_ID, PREV_DEBUG_CONSOLE_LABEL);
registerDebugCommandPaletteItem(SHOW_LOADED_SCRIPTS_ID, OPEN_LOADED_SCRIPTS_LABEL, CONTEXT_IN_DEBUG_MODE);
registerDebugCommandPaletteItem(SELECT_DEBUG_CONSOLE_ID, SELECT_DEBUG_CONSOLE_LABEL);
registerDebugCommandPaletteItem(SELECT_DEBUG_SESSION_ID, SELECT_DEBUG_SESSION_LABEL);
registerDebugCommandPaletteItem(CALLSTACK_TOP_ID, CALLSTACK_TOP_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(CALLSTACK_BOTTOM_ID, CALLSTACK_BOTTOM_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(CALLSTACK_UP_ID, CALLSTACK_UP_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugCommandPaletteItem(CALLSTACK_DOWN_ID, CALLSTACK_DOWN_LABEL, CONTEXT_IN_DEBUG_MODE, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
const registerDebugViewMenuItem = (menuId, id, title, order, when, precondition, group = 'navigation', icon) => {
    MenuRegistry.appendMenuItem(menuId, {
        group,
        when,
        order,
        icon,
        command: {
            id,
            title,
            icon,
            precondition
        }
    });
};
registerDebugViewMenuItem(MenuId.DebugCallStackContext, RESTART_SESSION_ID, RESTART_LABEL, 10, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('session')), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugCallStackContext, DISCONNECT_ID, DISCONNECT_LABEL, 20, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('session')), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugCallStackContext, DISCONNECT_AND_SUSPEND_ID, DISCONNECT_AND_SUSPEND_LABEL, 21, ( ContextKeyExpr.and(( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('session')), CONTEXT_SUSPEND_DEBUGGEE_SUPPORTED, CONTEXT_TERMINATE_DEBUGGEE_SUPPORTED)), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugCallStackContext, STOP_ID, STOP_LABEL, 30, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('session')), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugCallStackContext, PAUSE_ID, PAUSE_LABEL, 10, ( ContextKeyExpr.and(( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), ( ContextKeyExpr.and(( CONTEXT_DEBUG_STATE.isEqualTo('running')), ( CONTEXT_FOCUSED_SESSION_IS_NO_DEBUG.toNegated()))))));
registerDebugViewMenuItem(MenuId.DebugCallStackContext, CONTINUE_ID, CONTINUE_LABEL, 10, ( ContextKeyExpr.and(( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')))));
registerDebugViewMenuItem(MenuId.DebugCallStackContext, STEP_OVER_ID, STEP_OVER_LABEL, 20, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugViewMenuItem(MenuId.DebugCallStackContext, STEP_INTO_ID, STEP_INTO_LABEL, 30, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugViewMenuItem(MenuId.DebugCallStackContext, STEP_OUT_ID, STEP_OUT_LABEL, 40, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')));
registerDebugViewMenuItem(MenuId.DebugCallStackContext, TERMINATE_THREAD_ID, ( localize(5094, "Terminate Thread")), 10, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('thread')), undefined, 'termination');
registerDebugViewMenuItem(MenuId.DebugCallStackContext, RESTART_FRAME_ID, ( localize(5099, "Restart Frame")), 10, ( ContextKeyExpr.and(( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('stackFrame')), CONTEXT_RESTART_FRAME_SUPPORTED)), CONTEXT_STACK_FRAME_SUPPORTS_RESTART);
registerDebugViewMenuItem(MenuId.DebugCallStackContext, COPY_STACK_TRACE_ID, ( localize(5100, "Copy Call Stack")), 20, ( CONTEXT_CALLSTACK_ITEM_TYPE.isEqualTo('stackFrame')), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, VIEW_MEMORY_ID, ( localize(5101, "View Binary Data")), 15, CONTEXT_CAN_VIEW_MEMORY, CONTEXT_IN_DEBUG_MODE, 'inline', debugInspectMemory);
registerDebugViewMenuItem(MenuId.DebugVariablesContext, SET_VARIABLE_ID, ( localize(5102, "Set Value")), 10, ( ContextKeyExpr.or(CONTEXT_SET_VARIABLE_SUPPORTED, ( ContextKeyExpr.and(CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, CONTEXT_SET_EXPRESSION_SUPPORTED)))), ( CONTEXT_VARIABLE_IS_READONLY.toNegated()), '3_modification');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, COPY_VALUE_ID, COPY_VALUE_LABEL, 10, undefined, undefined, '5_cutcopypaste');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, COPY_EVALUATE_PATH_ID, COPY_EVALUATE_PATH_LABEL, 20, CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, undefined, '5_cutcopypaste');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, ADD_TO_WATCH_ID, ADD_TO_WATCH_LABEL, 100, CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, BREAK_WHEN_VALUE_IS_READ_ID, ( localize(5103, "Break on Value Read")), 200, CONTEXT_BREAK_WHEN_VALUE_IS_READ_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, BREAK_WHEN_VALUE_CHANGES_ID, ( localize(5104, "Break on Value Change")), 210, CONTEXT_BREAK_WHEN_VALUE_CHANGES_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugVariablesContext, BREAK_WHEN_VALUE_IS_ACCESSED_ID, ( localize(5105, "Break on Value Access")), 220, CONTEXT_BREAK_WHEN_VALUE_IS_ACCESSED_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugHoverContext, VIEW_MEMORY_ID, ( localize(5101, "View Binary Data")), 15, CONTEXT_CAN_VIEW_MEMORY, CONTEXT_IN_DEBUG_MODE, 'inline', debugInspectMemory);
registerDebugViewMenuItem(MenuId.DebugHoverContext, COPY_VALUE_ID, COPY_VALUE_LABEL, 10, undefined, undefined, '5_cutcopypaste');
registerDebugViewMenuItem(MenuId.DebugHoverContext, COPY_EVALUATE_PATH_ID, COPY_EVALUATE_PATH_LABEL, 20, CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, undefined, '5_cutcopypaste');
registerDebugViewMenuItem(MenuId.DebugHoverContext, ADD_TO_WATCH_ID, ADD_TO_WATCH_LABEL, 100, CONTEXT_VARIABLE_EVALUATE_NAME_PRESENT, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugHoverContext, BREAK_WHEN_VALUE_IS_READ_ID, ( localize(5103, "Break on Value Read")), 200, CONTEXT_BREAK_WHEN_VALUE_IS_READ_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugHoverContext, BREAK_WHEN_VALUE_CHANGES_ID, ( localize(5104, "Break on Value Change")), 210, CONTEXT_BREAK_WHEN_VALUE_CHANGES_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugHoverContext, BREAK_WHEN_VALUE_IS_ACCESSED_ID, ( localize(5105, "Break on Value Access")), 220, CONTEXT_BREAK_WHEN_VALUE_IS_ACCESSED_SUPPORTED, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.DebugWatchContext, ADD_WATCH_ID, ADD_WATCH_LABEL, 10, undefined, undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugWatchContext, EDIT_EXPRESSION_COMMAND_ID, ( localize(5106, "Edit Expression")), 20, ( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('expression')), undefined, '3_modification');
registerDebugViewMenuItem(MenuId.DebugWatchContext, SET_EXPRESSION_COMMAND_ID, ( localize(5102, "Set Value")), 30, ( ContextKeyExpr.or(( ContextKeyExpr.and(( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('expression')), CONTEXT_SET_EXPRESSION_SUPPORTED)), ( ContextKeyExpr.and(( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('variable')), CONTEXT_SET_VARIABLE_SUPPORTED)))), ( CONTEXT_VARIABLE_IS_READONLY.toNegated()), '3_modification');
registerDebugViewMenuItem(MenuId.DebugWatchContext, COPY_VALUE_ID, ( localize(5107, "Copy Value")), 40, ( ContextKeyExpr.or(( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('expression')), ( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('variable')))), CONTEXT_IN_DEBUG_MODE, '3_modification');
registerDebugViewMenuItem(MenuId.DebugWatchContext, VIEW_MEMORY_ID, ( localize(5101, "View Binary Data")), 10, CONTEXT_CAN_VIEW_MEMORY, undefined, 'inline', debugInspectMemory);
registerDebugViewMenuItem(MenuId.DebugWatchContext, REMOVE_EXPRESSION_COMMAND_ID, ( localize(5108, "Remove Expression")), 20, ( CONTEXT_WATCH_ITEM_TYPE.isEqualTo('expression')), undefined, 'inline', watchExpressionRemove);
registerDebugViewMenuItem(MenuId.DebugWatchContext, REMOVE_WATCH_EXPRESSIONS_COMMAND_ID, REMOVE_WATCH_EXPRESSIONS_LABEL, 20, undefined, undefined, 'z_commands');
registerDebugViewMenuItem(MenuId.NotebookVariablesContext, COPY_NOTEBOOK_VARIABLE_VALUE_ID, COPY_NOTEBOOK_VARIABLE_VALUE_LABEL, 20, CONTEXT_VARIABLE_VALUE);
if (isMacintosh) {
    const registerTouchBarEntry = (id, title, order, when, iconUri) => {
        MenuRegistry.appendMenuItem(MenuId.TouchBarContext, {
            command: {
                id,
                title,
                icon: { dark: iconUri }
            },
            when: ( ContextKeyExpr.and(CONTEXT_DEBUGGERS_AVAILABLE, when)),
            group: '9_debug',
            order
        });
    };
    registerTouchBarEntry(DEBUG_RUN_COMMAND_ID, DEBUG_RUN_LABEL, 0, ( CONTEXT_IN_DEBUG_MODE.toNegated()), ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/continue-tb.png')));
    registerTouchBarEntry(DEBUG_START_COMMAND_ID, DEBUG_START_LABEL, 1, ( CONTEXT_IN_DEBUG_MODE.toNegated()), ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/run-with-debugging-tb.png')));
    registerTouchBarEntry(CONTINUE_ID, CONTINUE_LABEL, 0, ( CONTEXT_DEBUG_STATE.isEqualTo('stopped')), ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/continue-tb.png')));
    registerTouchBarEntry(PAUSE_ID, PAUSE_LABEL, 1, ( ContextKeyExpr.and(CONTEXT_IN_DEBUG_MODE, ( ContextKeyExpr.and(( CONTEXT_DEBUG_STATE.isEqualTo('running')), ( CONTEXT_FOCUSED_SESSION_IS_NO_DEBUG.toNegated()))))), ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/pause-tb.png')));
    registerTouchBarEntry(STEP_OVER_ID, STEP_OVER_LABEL, 2, CONTEXT_IN_DEBUG_MODE, ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/stepover-tb.png')));
    registerTouchBarEntry(STEP_INTO_ID, STEP_INTO_LABEL, 3, CONTEXT_IN_DEBUG_MODE, ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/stepinto-tb.png')));
    registerTouchBarEntry(STEP_OUT_ID, STEP_OUT_LABEL, 4, CONTEXT_IN_DEBUG_MODE, ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/stepout-tb.png')));
    registerTouchBarEntry(RESTART_SESSION_ID, RESTART_LABEL, 5, CONTEXT_IN_DEBUG_MODE, ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/restart-tb.png')));
    registerTouchBarEntry(STOP_ID, STOP_LABEL, 6, CONTEXT_IN_DEBUG_MODE, ( FileAccess.asFileUri('vs/workbench/contrib/debug/browser/media/stop-tb.png')));
}
MenuRegistry.appendMenuItem(MenuId.EditorTitle, { submenu: MenuId.EditorTitleRun, rememberDefaultAction: true, title: ( localize2(5109, "Run or Debug...")), icon: debugRun, group: 'navigation', order: -1 });
MenuRegistry.appendMenuItem(MenuId.MenubarMainMenu, {
    submenu: MenuId.MenubarDebugMenu,
    title: {
        ...( localize2(5110, "Run")),
        mnemonicTitle: ( localize(5111, "&&Run"))
    },
    order: 6
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '1_debug',
    command: {
        id: DEBUG_START_COMMAND_ID,
        title: ( localize(5112, "&&Start Debugging"))
    },
    order: 1,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '1_debug',
    command: {
        id: DEBUG_RUN_COMMAND_ID,
        title: ( localize(5113, "Run &&Without Debugging"))
    },
    order: 2,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '1_debug',
    command: {
        id: STOP_ID,
        title: ( localize(5114, "&&Stop Debugging")),
        precondition: CONTEXT_IN_DEBUG_MODE
    },
    order: 3,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '1_debug',
    command: {
        id: RESTART_SESSION_ID,
        title: ( localize(5115, "&&Restart Debugging")),
        precondition: CONTEXT_IN_DEBUG_MODE
    },
    order: 4,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '2_configuration',
    command: {
        id: ADD_CONFIGURATION_ID,
        title: ( localize(5116, "A&&dd Configuration..."))
    },
    order: 2,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '3_step',
    command: {
        id: STEP_OVER_ID,
        title: ( localize(5117, "Step &&Over")),
        precondition: ( CONTEXT_DEBUG_STATE.isEqualTo('stopped'))
    },
    order: 1,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '3_step',
    command: {
        id: STEP_INTO_ID,
        title: ( localize(5118, "Step &&Into")),
        precondition: ( CONTEXT_DEBUG_STATE.isEqualTo('stopped'))
    },
    order: 2,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '3_step',
    command: {
        id: STEP_OUT_ID,
        title: ( localize(5119, "Step O&&ut")),
        precondition: ( CONTEXT_DEBUG_STATE.isEqualTo('stopped'))
    },
    order: 3,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '3_step',
    command: {
        id: CONTINUE_ID,
        title: ( localize(5120, "&&Continue")),
        precondition: ( CONTEXT_DEBUG_STATE.isEqualTo('stopped'))
    },
    order: 4,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarNewBreakpointMenu, {
    group: '1_breakpoints',
    command: {
        id: TOGGLE_INLINE_BREAKPOINT_ID,
        title: ( localize(5121, "Inline Breakp&&oint"))
    },
    order: 2,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: '4_new_breakpoint',
    title: ( localize(5122, "&&New Breakpoint")),
    submenu: MenuId.MenubarNewBreakpointMenu,
    order: 2,
    when: CONTEXT_DEBUGGERS_AVAILABLE
});
MenuRegistry.appendMenuItem(MenuId.MenubarDebugMenu, {
    group: 'z_install',
    command: {
        id: 'debug.installAdditionalDebuggers',
        title: ( localize(5123, "&&Install Additional Debuggers..."))
    },
    order: 1
});
const VIEW_CONTAINER = ( Registry.as(Extensions$2.ViewContainersRegistry)).registerViewContainer({
    id: DEBUG_PANEL_ID,
    title: ( localize2(5124, "Debug Console")),
    icon: debugConsoleViewIcon,
    ctorDescriptor: ( new SyncDescriptor(
        ViewPaneContainer,
        [DEBUG_PANEL_ID, { mergeViewWithContainerWhenSingleView: true }]
    )),
    storageId: DEBUG_PANEL_ID,
    hideIfEmpty: true,
    order: 2,
}, ViewContainerLocation.Panel, { doNotRegisterOpenCommand: true });
( Registry.as(Extensions$2.ViewsRegistry)).registerViews([{
        id: REPL_VIEW_ID,
        name: ( localize2(5124, "Debug Console")),
        containerIcon: debugConsoleViewIcon,
        canToggleVisibility: false,
        canMoveView: true,
        when: CONTEXT_DEBUGGERS_AVAILABLE,
        ctorDescriptor: ( new SyncDescriptor(Repl)),
        openCommandActionDescriptor: {
            id: 'workbench.debug.action.toggleRepl',
            mnemonicTitle: ( localize(5125, "De&&bug Console")),
            keybindings: { primary: KeyMod.CtrlCmd | KeyMod.Shift | KeyCode.KeyY },
            order: 2
        }
    }], VIEW_CONTAINER);
const viewContainer = ( Registry.as(Extensions$2.ViewContainersRegistry)).registerViewContainer({
    id: VIEWLET_ID,
    title: ( localize2(5126, "Run and Debug")),
    openCommandActionDescriptor: {
        id: VIEWLET_ID,
        mnemonicTitle: ( localize(5127, "&&Run")),
        keybindings: { primary: KeyMod.CtrlCmd | KeyMod.Shift | KeyCode.KeyD },
        order: 3
    },
    ctorDescriptor: ( new SyncDescriptor(DebugViewPaneContainer)),
    icon: runViewIcon,
    alwaysUseContainerInfo: true,
    order: 3,
}, ViewContainerLocation.Sidebar);
const viewsRegistry = ( Registry.as(Extensions$2.ViewsRegistry));
viewsRegistry.registerViews([{ id: VARIABLES_VIEW_ID, name: ( localize2(5128, "Variables")), containerIcon: variablesViewIcon, ctorDescriptor: ( new SyncDescriptor(VariablesView)), order: 10, weight: 40, canToggleVisibility: true, canMoveView: true, focusCommand: { id: 'workbench.debug.action.focusVariablesView' }, when: ( CONTEXT_DEBUG_UX.isEqualTo('default')) }], viewContainer);
viewsRegistry.registerViews([{ id: WATCH_VIEW_ID, name: ( localize2(5129, "Watch")), containerIcon: watchViewIcon, ctorDescriptor: ( new SyncDescriptor(WatchExpressionsView)), order: 20, weight: 10, canToggleVisibility: true, canMoveView: true, focusCommand: { id: 'workbench.debug.action.focusWatchView' }, when: ( CONTEXT_DEBUG_UX.isEqualTo('default')) }], viewContainer);
viewsRegistry.registerViews([{ id: CALLSTACK_VIEW_ID, name: ( localize2(5130, "Call Stack")), containerIcon: callStackViewIcon, ctorDescriptor: ( new SyncDescriptor(CallStackView)), order: 30, weight: 30, canToggleVisibility: true, canMoveView: true, focusCommand: { id: 'workbench.debug.action.focusCallStackView' }, when: ( CONTEXT_DEBUG_UX.isEqualTo('default')) }], viewContainer);
viewsRegistry.registerViews([{ id: BREAKPOINTS_VIEW_ID, name: ( localize2(5131, "Breakpoints")), containerIcon: breakpointsViewIcon, ctorDescriptor: ( new SyncDescriptor(BreakpointsView)), order: 40, weight: 20, canToggleVisibility: true, canMoveView: true, focusCommand: { id: 'workbench.debug.action.focusBreakpointsView' }, when: ( ContextKeyExpr.or(CONTEXT_BREAKPOINTS_EXIST, ( CONTEXT_DEBUG_UX.isEqualTo('default')), CONTEXT_HAS_DEBUGGED)) }], viewContainer);
viewsRegistry.registerViews([{ id: WelcomeView.ID, name: WelcomeView.LABEL, containerIcon: runViewIcon, ctorDescriptor: ( new SyncDescriptor(WelcomeView)), order: 1, weight: 40, canToggleVisibility: true, when: ( CONTEXT_DEBUG_UX.isEqualTo('simple')) }], viewContainer);
viewsRegistry.registerViews([{ id: LOADED_SCRIPTS_VIEW_ID, name: ( localize2(5132, "Loaded Scripts")), containerIcon: loadedScriptsViewIcon, ctorDescriptor: ( new SyncDescriptor(LoadedScriptsView)), order: 35, weight: 5, canToggleVisibility: true, canMoveView: true, collapsed: true, when: ( ContextKeyExpr.and(CONTEXT_LOADED_SCRIPTS_SUPPORTED, ( CONTEXT_DEBUG_UX.isEqualTo('default')))) }], viewContainer);
( Registry.as(EditorExtensions.EditorPane)).registerEditorPane(EditorPaneDescriptor.create(DisassemblyView, DISASSEMBLY_VIEW_ID, ( localize(5133, "Disassembly"))), [( new SyncDescriptor(DisassemblyViewInput))]);
const configurationRegistry = ( Registry.as(Extensions$3.Configuration));
configurationRegistry.registerConfiguration({
    id: 'debug',
    order: 20,
    title: ( localize(5134, "Debug")),
    type: 'object',
    properties: {
        'debug.showVariableTypes': {
            type: 'boolean',
            description: ( localize(5135, "Show variable type in variable pane during debug session")),
            default: false
        },
        'debug.allowBreakpointsEverywhere': {
            type: 'boolean',
            description: ( localize(5136, "Allow setting breakpoints in any file.")),
            default: false
        },
        'debug.gutterMiddleClickAction': {
            type: 'string',
            enum: ['logpoint', 'conditionalBreakpoint', 'triggeredBreakpoint', 'none'],
            description: ( localize(
                5137,
                'Controls the action to perform when clicking the editor gutter with the middle mouse button.'
            )),
            enumDescriptions: [
                ( localize(5138, "Add Logpoint.")),
                ( localize(5139, "Add Conditional Breakpoint.")),
                ( localize(5140, "Add Triggered Breakpoint.")),
                ( localize(5141, "Don't perform any action.")),
            ],
            default: 'logpoint',
        },
        'debug.openExplorerOnEnd': {
            type: 'boolean',
            description: ( localize(
                5142,
                "Automatically open the explorer view at the end of a debug session."
            )),
            default: false
        },
        'debug.closeReadonlyTabsOnEnd': {
            type: 'boolean',
            description: ( localize(
                5143,
                "At the end of a debug session, all the read-only tabs associated with that session will be closed"
            )),
            default: false
        },
        'debug.inlineValues': {
            type: 'string',
            'enum': ['on', 'off', 'auto'],
            description: ( localize(5144, "Show variable values inline in editor while debugging.")),
            'enumDescriptions': [
                ( localize(5145, "Always show variable values inline in editor while debugging.")),
                ( localize(5146, "Never show variable values inline in editor while debugging.")),
                ( localize(
                5147,
                "Show variable values inline in editor while debugging when the language supports inline value locations."
            )),
            ],
            default: 'auto'
        },
        'debug.toolBarLocation': {
            enum: ['floating', 'docked', 'commandCenter', 'hidden'],
            markdownDescription: ( localize(
                5148,
                "Controls the location of the debug toolbar. Either `floating` in all views, `docked` in the debug view, `commandCenter` (requires {0}), or `hidden`.",
                '`#window.commandCenter#`'
            )),
            default: 'floating',
            markdownEnumDescriptions: [
                ( localize(5149, "Show debug toolbar in all views.")),
                ( localize(5150, "Show debug toolbar only in debug views.")),
                ( localize(5151, "`(Experimental)` Show debug toolbar in the command center.")),
                ( localize(5152, "Do not show debug toolbar.")),
            ]
        },
        'debug.showInStatusBar': {
            enum: ['never', 'always', 'onFirstSessionStart'],
            enumDescriptions: [( localize(5153, "Never show debug in Status bar")), ( localize(5154, "Always show debug in Status bar")), ( localize(
                5155,
                "Show debug in Status bar only after debug was started for the first time"
            ))],
            description: ( localize(5156, "Controls when the debug Status bar should be visible.")),
            default: 'onFirstSessionStart'
        },
        'debug.internalConsoleOptions': INTERNAL_CONSOLE_OPTIONS_SCHEMA,
        'debug.console.closeOnEnd': {
            type: 'boolean',
            description: ( localize(
                5157,
                "Controls if the Debug Console should be automatically closed when the debug session ends."
            )),
            default: false
        },
        'debug.terminal.clearBeforeReusing': {
            type: 'boolean',
            description: ( localize(
                5158,
                "Before starting a new debug session in an integrated or external terminal, clear the terminal."
            )),
            default: false
        },
        'debug.openDebug': {
            enum: ['neverOpen', 'openOnSessionStart', 'openOnFirstSessionStart', 'openOnDebugBreak'],
            default: 'openOnDebugBreak',
            description: ( localize(5159, "Controls when the debug view should open."))
        },
        'debug.showSubSessionsInToolBar': {
            type: 'boolean',
            description: ( localize(
                5160,
                "Controls whether the debug sub-sessions are shown in the debug tool bar. When this setting is false the stop command on a sub-session will also stop the parent session."
            )),
            default: false
        },
        'debug.console.fontSize': {
            type: 'number',
            description: ( localize(5161, "Controls the font size in pixels in the Debug Console.")),
            default: isMacintosh ? 12 : 14,
        },
        'debug.console.fontFamily': {
            type: 'string',
            description: ( localize(5162, "Controls the font family in the Debug Console.")),
            default: 'default'
        },
        'debug.console.lineHeight': {
            type: 'number',
            description: ( localize(
                5163,
                "Controls the line height in pixels in the Debug Console. Use 0 to compute the line height from the font size."
            )),
            default: 0
        },
        'debug.console.wordWrap': {
            type: 'boolean',
            description: ( localize(5164, "Controls if the lines should wrap in the Debug Console.")),
            default: true
        },
        'debug.console.historySuggestions': {
            type: 'boolean',
            description: ( localize(
                5165,
                "Controls if the Debug Console should suggest previously typed input."
            )),
            default: true
        },
        'debug.console.collapseIdenticalLines': {
            type: 'boolean',
            description: ( localize(
                5166,
                "Controls if the Debug Console should collapse identical lines and show a number of occurrences with a badge."
            )),
            default: true
        },
        'debug.console.acceptSuggestionOnEnter': {
            enum: ['off', 'on'],
            description: ( localize(
                5167,
                "Controls whether suggestions should be accepted on Enter in the Debug Console. Enter is also used to evaluate whatever is typed in the Debug Console."
            )),
            default: 'off'
        },
        'launch': {
            type: 'object',
            description: ( localize(
                5168,
                "Global debug launch configuration. Should be used as an alternative to 'launch.json' that is shared across workspaces."
            )),
            default: { configurations: [], compounds: [] },
            $ref: launchSchemaId,
            disallowConfigurationDefault: true
        },
        'debug.focusWindowOnBreak': {
            type: 'boolean',
            description: ( localize(
                5169,
                "Controls whether the workbench window should be focused when the debugger breaks."
            )),
            default: true
        },
        'debug.focusEditorOnBreak': {
            type: 'boolean',
            description: ( localize(
                5170,
                "Controls whether the editor should be focused when the debugger breaks."
            )),
            default: true
        },
        'debug.onTaskErrors': {
            enum: ['debugAnyway', 'showErrors', 'prompt', 'abort'],
            enumDescriptions: [( localize(5171, "Ignore task errors and start debugging.")), ( localize(5172, "Show the Problems view and do not start debugging.")), ( localize(5173, "Prompt user.")), ( localize(5174, "Cancel debugging."))],
            description: ( localize(
                5175,
                "Controls what to do when errors are encountered after running a preLaunchTask."
            )),
            default: 'prompt'
        },
        'debug.showBreakpointsInOverviewRuler': {
            type: 'boolean',
            description: ( localize(
                5176,
                "Controls whether breakpoints should be shown in the overview ruler."
            )),
            default: false
        },
        'debug.showInlineBreakpointCandidates': {
            type: 'boolean',
            description: ( localize(
                5177,
                "Controls whether inline breakpoints candidate decorations should be shown in the editor while debugging."
            )),
            default: true
        },
        'debug.saveBeforeStart': {
            description: ( localize(5178, "Controls what editors to save before starting a debug session.")),
            enum: ['allEditorsInActiveGroup', 'nonUntitledEditorsInActiveGroup', 'none'],
            enumDescriptions: [
                ( localize(
                5179,
                "Save all editors in the active group before starting a debug session."
            )),
                ( localize(
                5180,
                "Save all editors in the active group except untitled ones before starting a debug session."
            )),
                ( localize(5181, "Don't save any editors before starting a debug session.")),
            ],
            default: 'allEditorsInActiveGroup',
            scope: ConfigurationScope.LANGUAGE_OVERRIDABLE
        },
        'debug.confirmOnExit': {
            description: ( localize(
                5182,
                "Controls whether to confirm when the window closes if there are active debug sessions."
            )),
            type: 'string',
            enum: ['never', 'always'],
            enumDescriptions: [
                ( localize(5183, "Never confirm.")),
                ( localize(5184, "Always confirm if there are debug sessions.")),
            ],
            default: 'never'
        },
        'debug.disassemblyView.showSourceCode': {
            type: 'boolean',
            default: true,
            description: ( localize(5185, "Show Source Code in Disassembly View."))
        },
        'debug.autoExpandLazyVariables': {
            type: 'string',
            enum: ['auto', 'on', 'off'],
            default: 'auto',
            enumDescriptions: [
                ( localize(
                5186,
                "When in screen reader optimized mode, automatically expand lazy variables."
            )),
                ( localize(5187, "Always automatically expand lazy variables.")),
                ( localize(5188, "Never automatically expand lazy variables."))
            ],
            description: ( localize(
                5189,
                "Controls whether variables that are lazily resolved, such as getters, are automatically resolved and expanded by the debugger."
            ))
        },
        'debug.enableStatusBarColor': {
            type: 'boolean',
            description: ( localize(5190, "Color of the Status bar when debugger is active.")),
            default: true
        },
        'debug.hideLauncherWhileDebugging': {
            type: 'boolean',
            markdownDescription: ( localize(
                5191,
                "Hide 'Start Debugging' control in title bar of 'Run and Debug' view while debugging is active. Only relevant when {0} is not `docked`.",
                '`#debug.toolBarLocation#`'
            )),
            default: false
        },
        'debug.hideSlowPreLaunchWarning': {
            type: 'boolean',
            markdownDescription: ( localize(
                5192,
                "Hide the warning shown when a `preLaunchTask` has been running for a while."
            )),
            default: false
        }
    }
});
AccessibleViewRegistry.register(( new ReplAccessibleView()));
AccessibleViewRegistry.register(( new ReplAccessibilityHelp()));
AccessibleViewRegistry.register(( new RunAndDebugAccessibilityHelp()));
registerWorkbenchContribution2(ReplAccessibilityAnnouncer.ID, ReplAccessibilityAnnouncer, WorkbenchPhase.AfterRestored);
registerWorkbenchContribution2(DebugWatchAccessibilityAnnouncer.ID, DebugWatchAccessibilityAnnouncer, WorkbenchPhase.AfterRestored);
