import { ActionBar } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/actionbar/actionbar";
import { IHighlight } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/highlightedlabel/highlightedLabel";
import { AsyncDataTree } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/tree/asyncDataTree";
import { ITreeContextMenuEvent, ITreeNode } from "@codingame/monaco-vscode-api/vscode/vs/base/browser/ui/tree/tree";
import { FuzzyScore } from "@codingame/monaco-vscode-api/vscode/vs/base/common/filters";
import { IDisposable } from "@codingame/monaco-vscode-api/vscode/vs/base/common/lifecycle";
import { MenuId } from "@codingame/monaco-vscode-api/vscode/vs/platform/actions/common/actions";
import { IMenuService } from "@codingame/monaco-vscode-api/vscode/vs/platform/actions/common/actions.service";
import { IConfigurationService } from "@codingame/monaco-vscode-api/vscode/vs/platform/configuration/common/configuration.service";
import { IContextKeyService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextkey/common/contextkey.service";
import { IContextMenuService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextview/browser/contextView.service";
import { IContextViewService } from "@codingame/monaco-vscode-api/vscode/vs/platform/contextview/browser/contextView.service";
import { IHoverService } from "@codingame/monaco-vscode-api/vscode/vs/platform/hover/browser/hover.service";
import { IInstantiationService } from "@codingame/monaco-vscode-api/vscode/vs/platform/instantiation/common/instantiation";
import { IKeybindingService } from "@codingame/monaco-vscode-api/vscode/vs/platform/keybinding/common/keybinding.service";
import { IOpenerService } from "@codingame/monaco-vscode-api/vscode/vs/platform/opener/common/opener.service";
import { ITelemetryService } from "@codingame/monaco-vscode-api/vscode/vs/platform/telemetry/common/telemetry.service";
import { IThemeService } from "@codingame/monaco-vscode-api/vscode/vs/platform/theme/common/themeService.service";
import { ViewPane } from "@codingame/monaco-vscode-65619f8f-0eab-5d8b-855a-43b6353fe527-common/vscode/vs/workbench/browser/parts/views/viewPane";
import { IViewletViewOptions } from "@codingame/monaco-vscode-55ed5668-e8ca-5335-a587-790bcf1200c0-common/vscode/vs/workbench/browser/parts/views/viewsViewlet";
import { IViewDescriptorService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/common/views.service";
import { IExpression, IScope, IViewModel } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debug";
import { IDebugService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debug.service";
import { IDebugVisualizerService } from "@codingame/monaco-vscode-api/vscode/vs/workbench/contrib/debug/common/debugVisualizers.service";
import { AbstractExpressionsRenderer, IExpressionTemplateData, IInputBoxOptions } from "./baseDebugView.js";
import { DebugExpressionRenderer } from "@codingame/monaco-vscode-88aa9a78-75f5-5aaa-89e9-bbdd580b3b5c-common/vscode/vs/workbench/contrib/debug/browser/debugExpressionRenderer";
export declare class VariablesView extends ViewPane {
    private readonly debugService;
    private readonly menuService;
    private updateTreeScheduler;
    private needsRefresh;
    private tree;
    private savedViewState;
    private autoExpandedScopes;
    constructor(options: IViewletViewOptions, contextMenuService: IContextMenuService, debugService: IDebugService, keybindingService: IKeybindingService, configurationService: IConfigurationService, instantiationService: IInstantiationService, viewDescriptorService: IViewDescriptorService, contextKeyService: IContextKeyService, openerService: IOpenerService, themeService: IThemeService, telemetryService: ITelemetryService, hoverService: IHoverService, menuService: IMenuService);
    protected renderBody(container: HTMLElement): void;
    protected layoutBody(width: number, height: number): void;
    focus(): void;
    collapseAll(): void;
    private onMouseDblClick;
    private canSetExpressionValue;
    private onContextMenu;
}
export declare function openContextMenuForVariableTreeElement(parentContextKeyService: IContextKeyService, menuService: IMenuService, contextMenuService: IContextMenuService, menuId: MenuId, e: ITreeContextMenuEvent<IExpression | IScope>): Promise<void>;
export declare class VisualizedVariableRenderer extends AbstractExpressionsRenderer {
    private readonly expressionRenderer;
    private readonly menuService;
    private readonly contextKeyService;
    static readonly ID = "viz";
    static rendererOnVisualizationRange(model: IViewModel, tree: AsyncDataTree<any, any, any>): IDisposable;
    constructor(expressionRenderer: DebugExpressionRenderer, debugService: IDebugService, contextViewService: IContextViewService, hoverService: IHoverService, menuService: IMenuService, contextKeyService: IContextKeyService);
    get templateId(): string;
    renderElement(node: ITreeNode<IExpression, FuzzyScore>, index: number, data: IExpressionTemplateData): void;
    protected renderExpression(expression: IExpression, data: IExpressionTemplateData, highlights: IHighlight[]): void;
    protected getInputBoxOptions(expression: IExpression): IInputBoxOptions | undefined;
    protected renderActionBar(actionBar: ActionBar, expression: IExpression, _data: IExpressionTemplateData): void;
}
export declare class VariablesRenderer extends AbstractExpressionsRenderer {
    private readonly expressionRenderer;
    private readonly menuService;
    private readonly contextKeyService;
    private readonly visualization;
    private readonly contextMenuService;
    static readonly ID = "variable";
    constructor(expressionRenderer: DebugExpressionRenderer, menuService: IMenuService, contextKeyService: IContextKeyService, visualization: IDebugVisualizerService, contextMenuService: IContextMenuService, debugService: IDebugService, contextViewService: IContextViewService, hoverService: IHoverService);
    get templateId(): string;
    protected renderExpression(expression: IExpression, data: IExpressionTemplateData, highlights: IHighlight[]): void;
    renderElement(node: ITreeNode<IExpression, FuzzyScore>, index: number, data: IExpressionTemplateData): void;
    protected getInputBoxOptions(expression: IExpression): IInputBoxOptions;
    protected renderActionBar(actionBar: ActionBar, expression: IExpression, data: IExpressionTemplateData): void;
    private pickVisualizer;
    private useVisualizer;
}
export declare const SET_VARIABLE_ID = "debug.setVariable";
export declare const VIEW_MEMORY_ID = "workbench.debug.viewlet.action.viewMemory";
export declare const BREAK_WHEN_VALUE_CHANGES_ID = "debug.breakWhenValueChanges";
export declare const BREAK_WHEN_VALUE_IS_ACCESSED_ID = "debug.breakWhenValueIsAccessed";
export declare const BREAK_WHEN_VALUE_IS_READ_ID = "debug.breakWhenValueIsRead";
